@@ -1,6 +1,6 @@
 package App::JobLog::Command;
 BEGIN {
-  $App::JobLog::Command::VERSION = '1.009';
+  $App::JobLog::Command::VERSION = '1.010';
 }
 
 # ABSTRACT: common functionality of App::JobLog commands
@@ -32,15 +32,40 @@ sub description {
     }
 
     # make sure things are wrapped nicely
-    require Text::WrapI18N;
-    $Text::WrapI18N::columns = columns;
-    $desc = Text::WrapI18N::wrap( '', '', $desc );
+    _wrap( \$desc );
 
     # space between description and options text
     $desc .= "\n";
     return $desc;
 }
 
+# performs text wrapping while preserving the formatting of lines beginning which whitespace
+sub _wrap {
+    my $desc = shift;
+    require Text::WrapI18N;
+    $Text::WrapI18N::columns = columns;
+    my ( $current, @gathered );
+    for my $line ( $$desc =~ /^(.*?)\s*$/mg ) {
+        if ( $line =~ /^\S/ ) {
+            if ($current) {
+                $current .= " $line";
+            }
+            else {
+                $current = $line;
+            }
+        }
+        else {
+            push @gathered, Text::WrapI18N::wrap( '', '', $current )
+              if defined $current;
+            push @gathered, $line;
+            $current = undef;
+        }
+    }
+    push @gathered, Text::WrapI18N::wrap( '', '', $current )
+      if defined $current;
+    $$desc = join "\n", @gathered;
+}
+
 # override to make full description
 sub full_description { }
 
@@ -74,7 +99,7 @@ App::JobLog::Command - common functionality of App::JobLog commands
 
 =head1 VERSION
 
-version 1.009
+version 1.010
 
 =head1 DESCRIPTION
 
